@@ -1,5 +1,5 @@
-dichotom <- function(data,out='numeric') {
-  if(!is.data.frame(data)) data <- data.frame(data)
+dichotom <- function(data, out = "numeric") {
+  data <- as.data.frame(data)
   res <- matrix(nrow=nrow(data),ncol=length(levels(data[,1])))
   for(i in 1:ncol(data)) {
     if(is.factor(data[,i])==FALSE) data[,i] <- factor(data[,i])
@@ -15,4 +15,4 @@ dichotom <- function(data,out='numeric') {
   res <- as.data.frame(res)
   if(out=='factor') for(i in 1:ncol(res)) res[,i] <- as.factor(res[,i])
   res
-}
\ No newline at end of file
+}
