@@ -1,4 +1,4 @@
-tabcontrib <- function(resmca, dim = 1, best = TRUE, dec = 2, shortlabs = FALSE) {
+tabcontrib <- function(resmca, dim = 1, best = TRUE, limit = NULL, dec = 2, shortlabs = FALSE) {
   
   # initial data frame of contributions
   df1 <- data.frame(varcat = names(resmca$var$weight), weight = resmca$var$weight)
@@ -8,7 +8,15 @@ tabcontrib <- function(resmca, dim = 1, best = TRUE, dec = 2, shortlabs = FALSE)
   df <- merge(merge(merge(merge(getvarnames(resmca), df1, by = "varcat"), df2, by = "varcat"), df3, by = "varcat"), df4, by = "varcat")
   df$sign <- sign(df$coord)
   
-  if(best) df <- df[df$ctr >= 100/nrow(df),]
+  if(best & is.null(limit)) { 
+    limit <- 100/nrow(df)
+  } else if (isFALSE(best)) {
+    limit <- 0
+  } else {
+    if(limit<0 | limit>100) stop("limit argument should be set between 0 and 100.")
+  }
+  
+  df <- df[df$ctr >= limit,]
   
   # ctr by variable
   w <- aggregate(cbind(ctrtot = ctr) ~ var, data = df, FUN = sum)
@@ -65,7 +73,7 @@ tabcontrib <- function(resmca, dim = 1, best = TRUE, dec = 2, shortlabs = FALSE)
   res$ctrdev[res$count>1] <- ""
   res$ctrvar[res$count>1] <- ""
   res <- res[, c("var", "cat", "weight", "cos2", "ctr1", "ctr2", "ctrtot", "cumctr", "ctrdev", "ctrvar")]
-  if(!shortlabs) names(res) <- c("Variable", "Category", "Weight", "Quality of representation","Contribution (left)", "Contribution (right)",
+  if(!shortlabs) names(res) <- c("Variable", "Category", "Weight", "Quality of representation","Contribution (negative side)", "Contribution (positive side)",
                                  "Total contribution", "Cumulated contribution", "Contribution of deviation", "Proportion to variable")
   return(res)
 }
